@@ -133,7 +133,7 @@ function onLoad() {
 function sortAccountList(accounttree)
 {
   var xulSortService = Components.classes["@mozilla.org/xul/xul-sort-service;1"].getService(Components.interfaces.nsIXULSortService);
-  xulSortService.Sort(accounttree, 'http://home.netscape.com/NC-rdf#FolderTreeName?sort=true', 'ascending');
+  xulSortService.sort(accounttree, 'http://home.netscape.com/NC-rdf#FolderTreeName?sort=true', 'ascending');
 }
 
 function selectServer(server, selectPage)
@@ -696,8 +696,8 @@ function onAccountClick(tree) {
 // show the page for the given server:
 // - save the old values
 // - start loading the new page
-function showPage(serverId, pageId) {
-
+function showPage(serverId, pageId) 
+{
   if (pageId == currentPageId &&
       serverId == currentServerId)
     return;
@@ -707,7 +707,7 @@ function showPage(serverId, pageId) {
 
   if (gSmtpHostNameIsIllegal) {
     gSmtpHostNameIsIllegal = false;
-    return false;
+    return;
   }
 
   // save the previous page
@@ -728,7 +728,6 @@ function showPage(serverId, pageId) {
   else if (serverId != currentServerId) {
     restorePage(pageId, serverId);
   }
-
 }
 
 // page has loaded
@@ -809,7 +808,7 @@ function getAccountValue(account, accountValues, type, slot, preftype, isGeneric
     accountValues[type] = new Array;
 
   // fill in the slot from the account if necessary
-  if (!(slot in accountValues[type]) || !accountValues[type][slot]) {
+  if (!(slot in accountValues[type]) || accountValues[type][slot] == undefined) {
     // dump("Array->Form: lazily reading in the " + slot + " from the " + type + "\n");
     var server;
     if (account)
